@@ -1,6 +1,7 @@
-const go = new Go();
-let mod, instance;
-WebAssembly.instantiateStreaming(fetch("main.wasm"), go.importObject).then((result) => {
+window.onload = function () {
+  const go = new Go();
+  let mod, instance;
+  WebAssembly.instantiateStreaming(fetch("main.wasm"), go.importObject).then((result) => {
     mod = result.module;
     instance = result.instance;
     // document.getElementById("gtree").disabled = false;
@@ -8,19 +9,20 @@ WebAssembly.instantiateStreaming(fetch("main.wasm"), go.importObject).then((resu
     console.clear();
     go.run(instance);
     instance = WebAssembly.instantiate(mod, go.importObject);
-});
+
+    // wasmで定義してる関数のloadが終わってないとダメなので以降の処理はこの位置にある
+    if (typeof window.gtree !== 'function') {
+      return;
+    }
+
+    gtree();
+  });
+};
 
 const clearMarkdown = () => {
   document.getElementById("in").value = "";
 };
 
-const generateTree = () => {
-  gtree();
-};
-window.onload = function () {
-  generateTree();
-};
-
 const copyToClipboard = () => {
   const tree = document.getElementById("treeView");
   if (tree === null) {
@@ -39,7 +41,7 @@ const resetParts = () => {
 
 const reset = () => {
   resetParts();
-  generateTree();
+  gtree();
 };
 
 const clearTxt = () => {
